pub struct PostgresBackendOptions { /* private fields */ }Expand description
PostgreSQL adapter tuning that does not change stored data.
Implementations
Sourceimpl PostgresBackendOptions
impl PostgresBackendOptions
Sourcepub const fn new(max_batch_items: NonZeroUsize) -> Self
pub const fn new(max_batch_items: NonZeroUsize) -> Self
Create options with the maximum number of items sent in one SQL batch.
Sourcepub const fn max_batch_items(self) -> usize
pub const fn max_batch_items(self) -> usize
Maximum number of items sent in one SQL batch.