Crate prolly_store_postgres

Crate prolly_store_postgres 

PostgreSQL store adapter for prolly-map.

Re-exports

pub use postgres::*;

Modules

postgres
Postgres adapter entry point.

Structs

RemoteNamedRoot
Raw named root manifest returned by a backend scan.
RemoteProllyStore
Generic adapter over a remote backend.
RemoteRootCondition
Serialized named-root value that must still match at transaction commit time.
RemoteTransactionConflict
Details for a failed backend-level transaction validation.

Enums

RemoteBatchOp
Batch operation passed to a remote backend.
RemoteManifestUpdate
Result of a backend-level root compare-and-swap.
RemoteRootWrite
Serialized named-root write staged by a transaction.
RemoteTransactionUpdate
Result of a backend-level transaction commit.

Traits

RemoteStoreBackend
Backend capability contract used by all provider adapters.